@@ -10,7 +10,7 @@ console.setFormatter(formatter)
 logger = logging.getLogger("deck")
 logger.addHandler(console)
 
-__VERSION__ = "0.6.0"
+__VERSION__ = "0.7.1"
 
 DECKFILE_FILE = "deck.yaml"
 
@@ -25,8 +25,8 @@ class ClientConfiguration(object):
 
         if docker_client:
             self.DOCKER = docker_client
-        self.TOOLER_BASE_IMAGE = "quay.io/getdeck/tooler"
-        self.TOOLER_USER_IMAGE = "deck-tooler"
+        self.TOOLER_BASE_IMAGE = f"quay.io/getdeck/tooler:{__VERSION__}"
+        self.TOOLER_USER_IMAGE = f"deck-tooler:{__VERSION__}"
         self.deckfile_selector = deckfile_selector
         self.CLI_KUBECONFIG_DIRECTORY = os.path.expanduser("~/.deck/")
         if not os.path.exists(self.CLI_KUBECONFIG_DIRECTORY):
